@@ -77,6 +77,11 @@ def lndir(srcdir: Path, dstdir: Path, force_copy=False):
 def testing_metrics():
     return { 'bytes allocated', 'peak_megabytes_allocated', 'max_bytes_used' }
 
+# All performance counters we consider to be stable enough in CI to
+# test for.
+def stable_perf_counters():
+    return { 'instructions:u' }
+
 # Metrics which are testing residency information
 def residency_testing_metrics():
     return { 'peak_megabytes_allocated', 'max_bytes_used' }
@@ -160,5 +165,8 @@ def shorten_metric_name(name: str) -> str:
         "compile_time/bytes allocated": "ghc/alloc",
         "compile_time/peak_megabytes_allocated": "ghc/peak",
         "compile_time/max_bytes_used": "ghc/max",
+        "binary_size/if_compression(1)": "size/1",
+        "binary_size/if_compression(2)": "size/2",
+        "binary_size/if_compression(3)": "size/3",
     }
     return dic.get(name, name)
